# radnn - Rapid Deep Neural Networks

A library that brings the Rapid Application Development (RAD) approach into the lifecycle of Deep Learning models. Adapts objects from other frameworks and hides their implementation details to put emphasis on:

- Experiments: Data, Models, Training, Reproducibility
- Management: Process, Storage, Deployment
- Evaluation: Metrics, Plots, Visualizations
- Integration: IPC, Web API